@@ -1,7 +1,11 @@
 package HTML::Feature::Decoder;
 use strict;
 use warnings;
-use Data::Decode qw(Encode::Guess Encode::Guess::JP Encode::HTTP::Response);
+use Data::Decode;
+use Data::Decode::Chain;
+use Data::Decode::Encode::Guess;
+use Data::Decode::Encode::Guess::JP;
+use Data::Decode::Encode::HTTP::Response;
 use base qw(HTML::Feature::Base);
 
 __PACKAGE__->mk_accessors($_) for qw(decoder);
@@ -16,11 +20,13 @@ sub new {
 sub _setup {
     my $self    = shift;
     my $decoder = Data::Decode->new(
-        decoder => [
-            Data::Decode::Encode::HTTP::Response->new,
-            Data::Decode::Encode::Guess::JP->new,
-            Data::Decode::Encode::Guess->new,
-        ]
+        strategy => Data::Decode::Chain->new(
+            decoder => [
+                Data::Decode::Encode::HTTP::Response->new,
+                Data::Decode::Encode::Guess::JP->new,
+                Data::Decode::Encode::Guess->new,
+            ]
+        )
     );
     $self->decoder($decoder);
 }
